import shutil
import os
import pytest
import logging

from kvalikirstu2 import argument_parser

TEST_FILES_SRC = os.path.join(os.path.dirname(__file__), "test files src")
TEST_FILES_DST = os.path.join(os.path.dirname(__file__), "test files")
VARS = {'display': None}


def get_test_dir():
    return TEST_FILES_DST


@pytest.fixture(scope="session", autouse=True)
def setup(request):
    if os.path.exists(TEST_FILES_DST):
        shutil.rmtree(TEST_FILES_DST)
    shutil.copytree(TEST_FILES_SRC, TEST_FILES_DST)
    request.addfinalizer(finalize)
    setup_rootlogger()

    if os.name == "posix" and (all(not os.getenv(x) for x in ["DISPLAY", "NO_WX"])):
        import pyvirtualdisplay
        VARS['display'] = pyvirtualdisplay.Display()
        VARS['display'].start()
    argument_parser.Settings().set_up_cli_settings([])


def rootlogger_error(*args, **kwargs):
    raise Exception("Called root logger!")


def setup_rootlogger():
    logging.error = rootlogger_error
    logging.info = rootlogger_error
    logging.debug = rootlogger_error
    logging.warn = rootlogger_error
    logging.warning = rootlogger_error


def finalize():
    shutil.rmtree(TEST_FILES_DST)
    if VARS['display']:
        VARS['display'].stop()
