""" Tests the localization module
"""

import unittest
from kvalikirstu2 import localization
from kvalikirstu2.localization import _


class TestLocalization(unittest.TestCase):
    def test_finnish(self):
        finnish = localization.get_translation_func("fi_FI")
        self.assertEqual("Kohde", finnish("Subject"))
        self.assertEqual("Hakemisto", finnish("Index"))

        localization.set_language("fi_FI")
        self.assertEqual("Kohde", _("Subject"))
        self.assertEqual("Hakemisto", _("Index"))

    def test_english(self):
        english = localization.get_translation_func("en_US")
        self.assertEqual("Subject", english("Subject"))
        self.assertEqual("Index", english("Index"))

        localization.set_language("en_US")
        self.assertEqual("Subject", _("Subject"))
        self.assertEqual("Index", _("Index"))

    def test_languages(self):
        translations = localization.get_languages('en_US')
        self.assertIn(('en_US', 'English (United States)'), translations)
        self.assertIn(('fi_FI', 'Finnish (Finland)'), translations)
        self.assertNotIn(('nus_SS', 'Nuer (South Sudan)'), translations)
