import unittest
from kvalikirstu2 import paragraph_analyzer


class TestParagraphAnalyzer(unittest.TestCase):
    """Unit tests for the paragraph_analyzer module."""
    def test_invalid_types(self):
        begindata_with_lines = paragraph_analyzer.Paragraph(None, par_type=paragraph_analyzer.ParagraphType.BEGINDATA)
        begindata_with_lines.lines.append('a')
        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            begindata_with_lines.check_valid()

        unknown_par = paragraph_analyzer.Paragraph(None, par_type=paragraph_analyzer.ParagraphType.UNKNOWN)
        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            unknown_par.check_valid()

    def test_invalid_headers(self):
        invalid_header_par = paragraph_analyzer.Paragraph(None, par_type=paragraph_analyzer.ParagraphType.HEADER)
        invalid_header_par.lines.append('a')

        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            invalid_header_par.check_valid()

    def test_set_non_header_paragraph_to_headers(self):
        begindata_par = paragraph_analyzer.Paragraph(None, par_type=paragraph_analyzer.ParagraphType.BEGINDATA)
        subject = paragraph_analyzer.Subject(None, None)
        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            subject.set_headers(begindata_par)

    def test_subject_comparison_with_other_type(self):
        self.assertNotEqual(paragraph_analyzer.Subject(None, None), 1)

    def test_paragraph_splitting(self):
        par = paragraph_analyzer.Paragraph("", par_type=paragraph_analyzer.ParagraphType.HEADER)
        par.lines = ['q: 1', 'w: 2', 'e: 3', 'r: 4']
        self.assertFalse(par.should_split(None))
        par.lines.append('t')
        self.assertTrue(par.should_split(None))
        self.assertEqual(4, par.get_split_point(None))
        par1, par2 = par.split_paragraph(4)

        self.assertTrue(par1.manual_type)  # Make sure that a split paragraph's type cannot be altered later.
        self.assertTrue(par2.manual_type)

        self.assertEqual('r: 4', par1.lines[3])
        self.assertEqual('t', par2.lines[0])

    def test_split_non_header(self):
        par = paragraph_analyzer.Paragraph("", par_type=paragraph_analyzer.ParagraphType.UNKNOWN)
        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            par.get_split_point(None)

    def test_add_invalid_header_paragraph(self):
        subj = paragraph_analyzer.Subject(None, None)
        par = paragraph_analyzer.Paragraph("", par_type=paragraph_analyzer.ParagraphType.HEADER)
        par.lines.append('a')
        with self.assertRaises(paragraph_analyzer.ParagraphParsingException):
            subj.set_headers(par)
