import os
import tempfile
import unittest
from kvalikirstu2 import odt_reader, reader
from tests import test_writer
from odf.opendocument import load


class TestReader(unittest.TestCase):
    """Unit tests for the reader module."""
    def test_invalid_file(self):
        self.assertIsNone(reader.get_reader("bad.png"))
        with tempfile.TemporaryDirectory() as temp_dir:
            temp_file = os.path.join(temp_dir, "file")
            with open(temp_file, mode='w'):
                pass
            self.assertIsNone(reader.get_reader(temp_file))

    def test_invisible_text_odt(self):
        path = os.path.join(os.path.dirname(__file__), 'test files', 'invisible text.odt')
        odt_reader = reader.get_reader(path)
        lines = []
        while odt_reader.can_read():
            line = odt_reader.read_line()
            if line and not line.isspace():
                lines.append(line)
        self.assertEqual(lines[0], 'ID: ')

    def test_text_not_in_topnode(self):
        """The program used to get all the text from the topnode, but in some cases the text might not be there.
        """
        path = os.path.join(os.path.dirname(__file__), 'test files', 'text_not_in_topnode.odt')
        lines = test_writer.read_lines_from_file(path)
        self.assertEqual(lines[0], 'Testi')
