""" Tests the paragraph reader.
"""
import pytest
import unittest
import os
from kvalikirstu2 import header_scanner
from kvalikirstu2 import study_reader
from kvalikirstu2 import study
from kvalikirstu2 import argument_parser


@pytest.fixture(name='testdir')
def get_testdir():
    return os.path.join(os.path.dirname(__file__), "test files")


@pytest.fixture(name='settings')
def set_up_settings_class():
    return argument_parser.Settings()


@pytest.fixture(name='test_id')
def get_test_id():
    return 'test_id'


@pytest.fixture(name='store_args')
def store_test_args(settings, testdir):
    settings.parse_command_line([None, '--path', testdir, '--parse'])
    argument_parser.store_settings(settings.settings)


class TestSerialization(unittest.TestCase):
    @pytest.fixture(autouse=True)
    def init_reader_valid(self, testdir, test_id, store_args):
        store_args
        self.reader = study_reader.StudyReader(study_id=test_id, study_path=testdir, study_title="", data_folder_name="data")

    """For testing the serialization in the utils module"""
    def test_study_reader(self):
        print(self.reader)

    def test_study(self):
        """Tests reading a study and writing it to file."""
        # First read the study
        loaded_study = self.reader.get_study()
        loaded_study.write_to_file()

        # Load a copy of the study from file
        copy = study.Study(study_id=self.reader.study_id, study_path=self.reader.study_path, study_title="")
        copy.load_from_file()
        os.unlink(loaded_study.get_full_path())

        self.assertEqual(copy, loaded_study)

    def test_remap(self):
        """Tests remapping headers and values"""
        loaded_study = self.reader.get_study()
        header_info = header_scanner.get_header_info_for_study(self.reader.get_data_path())
        header_info.header_mapping["AMMATTI"] = "AE"
        header_info.value_mapping[str(("AMMATTI", "Ensihoitaja"))] = "EH"
        loaded_study.write_to_file()

        # Load a copy of the study from file
        copy = study.Study(self.reader.study_id, self.reader.study_path, "")
        copy.load_from_file()
        copy.remap_headers(header_info)

        assert copy.subjects[2].headers["AE"] == "EH"
        os.unlink(loaded_study.get_full_path())


if __name__ == '__main__':
    unittest.main()
