import unittest
import os
from kvalikirstu2 import argument_parser
from kvalikirstu2 import study
from kvalikirstu2 import paragraph_analyzer


class TestStudy(unittest.TestCase):
    """Unit tests for the study module."""
    def setUp(self):
        argument_parser.Settings().parse_gui(['--max-backup-folder-size', '0'])

    def test_empty_path_is_cwd(self):
        temp_study = study.Study("x", None, None)
        self.assertEqual(os.path.join(os.getcwd(), "temp", "x_full.json"), temp_study.get_full_path())

    def test_add_empty_subject(self):
        temp_study = study.Study("x", None, None)
        subject = paragraph_analyzer.Subject(None, None)
        temp_study.add_subject(subject)
        self.assertFalse(temp_study.subjects)

    def test_update_headers_names_correct(self):
        test_info = study.HeaderInfo()
        test_info.add_header('a')
        test_info.add_header('b')
        test_info.add_header('c')
        test_info.add_header('d')
        test_info.init_builtin_headers()
        test_info.header_mapping['a'] = 'e'
        test_info.update_headers()
        self.assertNotIn('a', test_info.header_mapping)
        self.assertIn('b', test_info.header_mapping)
        self.assertIn('c', test_info.header_mapping)
        self.assertIn('d', test_info.header_mapping)
        self.assertIn('e', test_info.header_mapping)
        self.assertNotIn('Folder', test_info.header_mapping)

    def test_value_mapping(self):
        test_info = study.HeaderInfo()
        test_info.add_header('a')
        test_info.header_mapping['a'] = 'c'
        test_info.value_mapping["('a', 'b')"] = 'c'
        test_info.value_mapping["('a', 'd')"] = 'd'
        test_info.update_headers()
        self.assertEqual('c', test_info.value_mapping["('c', 'c')"])
        self.assertEqual('d', test_info.value_mapping["('c', 'd')"])
