# Skip this module if NO_WX in env
import pytest
import os
if os.getenv('NO_WX'):
    pytest.skip('Skipping module because wxPython is not available', allow_module_level=True)

import unittest
import os
import tempfile
import wx
from unittest import mock
from kvalikirstu2 import argument_parser
from kvalikirstu2 import gui_model
from kvalikirstu2 import tmp_edit_window
from kvalikirstu2 import kvali_interface
from kvalikirstu2 import paragraph_analyzer
from kvalikirstu2 import writer


class TestParagraphErrorWindow(unittest.TestCase):
    @mock.patch('kvalikirstu2.tmp_edit_window.TmpEditWindow.ShowModal')
    @mock.patch('kvalikirstu2.tmp_edit_window.ParagraphErrorWindow.EndModal')
    def test_open_pressed(self, _, __):
        with tempfile.TemporaryDirectory() as temp_dir:
            filepath = os.path.join(temp_dir, "test.txt.temp")
            writer.write_txt(filepath)
            model = gui_model.GUIModel()

            self.app = wx.App()
            argument_parser.Settings().parse_gui([])
            exception = paragraph_analyzer.ParagraphParsingException(filepath, 0, 1)
            self.window = tmp_edit_window.ParagraphErrorWindow(model, '', exception)
            self.window._open_pressed(None)

    @mock.patch('kvalikirstu2.tmp_edit_window.ParagraphErrorWindow.ShowModal')
    def test_open_temp_error(self, _):
        with tempfile.TemporaryDirectory() as temp_dir:
            filepath = os.path.join(temp_dir, "test.txt.temp")
            writer.write_txt(filepath)
            model = gui_model.GUIModel()

            self.app = wx.App()
            argument_parser.Settings().parse_gui([])
            exception = paragraph_analyzer.ParagraphParsingException(filepath, 0, 1)
            tmp_edit_window.open_temp_error(model, '', exception)


class TestTmpEditWindow(unittest.TestCase):
    @mock.patch('kvalikirstu2.tmp_edit_window.TmpEditWindow.ShowModal')
    @mock.patch('wx.Dialog.EndModal')
    @mock.patch('wx.MessageBox')
    def test_save_pressed(self, _, __, ___):
        with tempfile.TemporaryDirectory() as temp_dir:
            filepath = os.path.join(temp_dir, "test.txt.temp")
            writer.write_txt(filepath)
            model = gui_model.GUIModel()

            self.app = wx.App()
            argument_parser.Settings().parse_gui([])
            exception = paragraph_analyzer.ParagraphParsingException(filepath, 0, 1)
            self.window = tmp_edit_window.TmpEditWindow(model, exception, None)

            self.window.styled_ctrl.SetText('asd')
            self.window._save_pressed()

            content = kvali_interface.get_textfile_content(filepath)
            self.assertEqual('asd%s' % os.linesep, content)
